@@ -35,12 +35,6 @@ classes.A = function() {
 goog.inherits(classes.A, classes.C);
 
 
-/**
- * Prevent renaming of class. Needed for reflection.
- */
-goog.exportSymbol('classes.A', classes.A);
-
-
 /**
  * Metadata
  *
@@ -57,8 +51,6 @@ classes.A.prototype.ROYALE_CLASS_INFO = { names: [{ name: 'A', qName: 'classes.A
  */
 classes.A.prototype.ROYALE_REFLECTION_INFO = function () {
   return {
-    variables: function () {return {};},
-    accessors: function () {return {};},
     methods: function () {
       return {
         'A': { type: '', declaredBy: 'classes.A'}
@@ -67,8 +59,7 @@ classes.A.prototype.ROYALE_REFLECTION_INFO = function () {
   };
 };
 /**
- * @export
  * @const
  * @type {number}
  */
-classes.A.prototype.ROYALE_REFLECTION_INFO.compileFlags = 9;
+classes.A.prototype.ROYALE_COMPILE_FLAGS = 9;
